@@ -19,7 +19,6 @@
 # In applying this license, CERN does not waive the privileges and immunities
 # granted to it by virtue of its status as an Intergovernmental Organization
 # or submit itself to any jurisdiction.
-import six
 
 from pypeg2 import Parser
 
@@ -37,27 +36,13 @@ class StatefulParser(Parser):
             Signifies whether we are parsing a parenthesized simple values expression. Used for disabling the simple
             values parsing related check "stop on INSPIRE keyword", for allowing parsing more expressions and not
             restrict the input accepted by the parser.
+
+        _parsing_texkey_expression (bool):
+            Signifies whether we are parsing a `texkey` expression which has special value in which we must accept ':'.
     """
 
     def __init__(self):
         super(StatefulParser, self).__init__()
         self._parsing_parenthesized_terminal = False
         self._parsing_parenthesized_simple_values_expression = False
-
-
-def parse(text, thing):
-    """Wrapper method for creating a StatefulParser and then parsing text with thing grammar.
-
-
-    Raises:
-        SyntaxError: if text does not match the grammar in thing
-        ValueError:  if input does not match types
-        TypeError:   if output classes have wrong syntax for __init__()
-        GrammarTypeError:   if grammar contains an object of unknown type
-        GrammarValueError:  if grammar contains an illegal cardinality value
-    """
-    parser = StatefulParser()
-    t, r = parser.parse(text, thing)
-    if t:
-        raise parser.last_error
-    return r
+        self._parsing_texkey_expression = False
